@@ -282,7 +282,11 @@ impl Actor {
         lua.load(source).eval()
     }
 
-    pub fn call(&self, name: &'static str, args: MultiLuaMessage) -> Result<LuaMessage, Error> {
+    pub fn call(
+        &self,
+        name: &'static str,
+        args: impl Into<MultiLuaMessage> + Clone + Sync + Send + 'static,
+    ) -> Result<LuaMessage, Error> {
         match self.handler.clone() {
             Some(_handler) => {
                 let lua = self.lua.clone();
@@ -293,7 +297,11 @@ impl Actor {
             None => Self::_call(&self.lua.clone(), name, args),
         }
     }
-    pub fn call_nowait(&self, name: &'static str, args: MultiLuaMessage) -> Result<(), Error> {
+    pub fn call_nowait(
+        &self,
+        name: &'static str,
+        args: impl Into<MultiLuaMessage> + Clone + Sync + Send + 'static,
+    ) -> Result<(), Error> {
         match self.handler.clone() {
             Some(_handler) => {
                 let lua = self.lua.clone();
@@ -311,14 +319,14 @@ impl Actor {
     fn _call(
         lua: &Arc<Mutex<Lua>>,
         name: &str,
-        args: MultiLuaMessage,
+        args: impl Into<MultiLuaMessage>,
     ) -> Result<LuaMessage, Error> {
         let vm = lua.lock().unwrap();
         vm.context(|lua| {
             lua.globals()
                 .get::<_, Function>(name)
                 .unwrap()
-                .call::<_, _>(args)
+                .call::<_, _>(args.into())
         })
     }
     /*
@@ -338,7 +346,7 @@ impl Actor {
 #[test]
 fn test_actor_new() {
     use rlua::Variadic;
-    use std::iter::FromIterator;
+    // use std::iter::FromIterator;
 
     fn test_actor(act: Actor) {
         let _ = act.exec_nowait(
@@ -365,7 +373,7 @@ fn test_actor_new() {
         )
         .ok()
         .unwrap();
-        match act.call("testit", LuaMessage::from(1).into()) {
+        match act.call("testit", 1) {
             Ok(_v) => {
                 assert_eq!(Some(2), Option::from(_v));
             }
@@ -387,7 +395,8 @@ fn test_actor_new() {
         match act.call(
             "testlist",
             // Vec::<LuaMessage>::from_iter([3.into(), 2.into()]).into(),
-            LuaMessage::from_iter([3.into(), 2.into()]).into(),
+            // LuaMessage::from_iter([3.into(), 2.into()]),
+            LuaMessage::from_slice([3, 2]),
         ) {
             Ok(_v) => {
                 assert_eq!(Some(2), Option::from(_v));
@@ -409,7 +418,10 @@ fn test_actor_new() {
         println!("222");
         match act.call(
             "testvargs",
-            Variadic::<LuaMessage>::from_iter([6.into(), 7.into()]).into(),
+            // Variadic::<LuaMessage>::from_iter([6.into(), 7.into()]),
+            // Vec::<LuaMessage>::from([6.into(), 7.into()]),
+            // MultiLuaMessage::from_slice([6, 7]),
+            (6, 7.0, ""),
         ) {
             Ok(_v) => {
                 assert_eq!(Some(13), Option::from(_v));
